@@ -185,13 +185,16 @@ Align_interface::align_elements_to_extents (Grob * me, Axis a)
     prevent ugly cyclic dependencies that arise when you combine
     self-alignment on a child with alignment of children.
   */
+ static SCM  prop_syms[2];
 
-  String s ("self-alignment-");
-
-  s += (a == X_AXIS) ? "X" : "Y";
-
-  SCM align (me->get_grob_property (s.ch_C ()));
-     
+  if (!prop_syms[0])
+    {
+      prop_syms[X_AXIS] = ly_symbol2scm ("self-alignment-X");
+      prop_syms[Y_AXIS] = ly_symbol2scm ("self-alignment-Y");
+    }
+  
+  SCM align (me->internal_get_grob_property (prop_syms[a]));
+  
   Array<Real> translates ;
   Interval total;
   Real where_f=0;
@@ -276,11 +279,6 @@ Align_interface::set_axis (Grob*me,Axis a)
   Axis_group_interface::set_axes (me, a,a);
 }
 
-bool
-Align_interface::has_interface (Grob*me)
-{
-  return me && me->has_interface (ly_symbol2scm ("align-interface"));
-}
 
 
 ADD_INTERFACE (Align_interface, "align-interface",
@@ -288,7 +286,10 @@ ADD_INTERFACE (Align_interface, "align-interface",
   "forced-distance stacking-dir align-dir threshold alignment-done center-element elements axes");
 
 
-
+struct Foobar
+{
+  bool has_interface (Grob*);
+};
 ADD_INTERFACE (Foobar, "aligned-interface",
   "read by align-interface",
   "minimum-space-pair extra-space");
